| Title: | Two Games to Relieve the Boredom |
|---|---|
| Description: | There are two interesting games in this package, one is 2048 games(for windows), using up and down to control the direction until there is a 2048 figure. And the other is 'what to eat today',preparing for people who choose difficulties, including most of the delicious Cantonese cuisine. |
| Authors: | Xiuwen Wang |
| Maintainer: | Xiuwen Wang <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-06-03 07:06:16 UTC |
| Source: | https://github.com/cran/happytime |
The adjacent numbers can be added if they are equal. When the maximum number reaches 2048, you win.
run2048()run2048()
run2048()run2048()
A small program is used to decide what to eat today, and currently only contains delicious Guangdong dishes.
runfood()runfood()
runfood()runfood()